@@ -20,9 +20,9 @@ class KDECONNECTCORE_EXPORT LinkProvider : public QObject
 
 public:
     LinkProvider();
-    ~LinkProvider() override = default;
 
     virtual QString name() = 0;
+    virtual int priority() = 0;
 
 public Q_SLOTS:
     virtual void onStart() = 0;
