@@ -17,10 +17,10 @@
 #include <core/device.h>
 #include <dbushelper.h>
 
-#include "dbusproperties.h"
-#include "mprisplayer.h"
-#include "mprisroot.h"
-#include "plugin_mpris_debug.h"
+#include "generated/systeminterfaces/dbusproperties.h"
+#include "generated/systeminterfaces/mprisplayer.h"
+#include "generated/systeminterfaces/mprisroot.h"
+#include "plugin_mpriscontrol_debug.h"
 
 K_PLUGIN_CLASS_WITH_JSON(MprisControlPlugin, "kdeconnect_mpriscontrol.json")
 
@@ -61,12 +61,12 @@ void MprisControlPlugin::serviceOwnerChanged(const QString &serviceName, const Q
         return;
 
     if (!oldOwner.isEmpty()) {
-        qCDebug(KDECONNECT_PLUGIN_MPRIS) << "MPRIS service" << serviceName << "just went offline";
+        qCDebug(KDECONNECT_PLUGIN_MPRISCONTROL) << "MPRIS service" << serviceName << "just went offline";
         removePlayer(serviceName);
     }
 
     if (!newOwner.isEmpty()) {
-        qCDebug(KDECONNECT_PLUGIN_MPRIS) << "MPRIS service" << serviceName << "just came online";
+        qCDebug(KDECONNECT_PLUGIN_MPRISCONTROL) << "MPRIS service" << serviceName << "just came online";
         addPlayer(serviceName);
     }
 }
@@ -94,7 +94,7 @@ void MprisControlPlugin::addPlayer(const QString &service)
     connect(player.propertiesInterface(), &OrgFreedesktopDBusPropertiesInterface::PropertiesChanged, this, &MprisControlPlugin::propertiesChanged);
     connect(player.mediaPlayer2PlayerInterface(), &OrgMprisMediaPlayer2PlayerInterface::Seeked, this, &MprisControlPlugin::seeked);
 
-    qCDebug(KDECONNECT_PLUGIN_MPRIS) << "Mpris addPlayer" << service << "->" << uniqueName;
+    qCDebug(KDECONNECT_PLUGIN_MPRISCONTROL) << "Mpris addPlayer" << service << "->" << uniqueName;
     sendPlayerList();
 }
 
@@ -107,7 +107,7 @@ void MprisControlPlugin::seeked(qlonglong position)
         return (player.mediaPlayer2PlayerInterface() == mediaPlayer2PlayerInterface);
     });
     if (it == end) {
-        qCWarning(KDECONNECT_PLUGIN_MPRIS) << "Seeked signal received for no longer tracked service" << mediaPlayer2PlayerInterface->service();
+        qCWarning(KDECONNECT_PLUGIN_MPRISCONTROL) << "Seeked signal received for no longer tracked service" << mediaPlayer2PlayerInterface->service();
         return;
     }
 
@@ -119,17 +119,15 @@ void MprisControlPlugin::seeked(qlonglong position)
     sendPacket(np);
 }
 
-void MprisControlPlugin::propertiesChanged(const QString &propertyInterface, const QVariantMap &properties)
+void MprisControlPlugin::propertiesChanged(const QString & /*propertyInterface*/, const QVariantMap &properties)
 {
-    Q_UNUSED(propertyInterface);
-
     OrgFreedesktopDBusPropertiesInterface *propertiesInterface = (OrgFreedesktopDBusPropertiesInterface *)sender();
     const auto end = playerList.constEnd();
     const auto it = std::find_if(playerList.constBegin(), end, [propertiesInterface](const MprisPlayer &player) {
         return (player.propertiesInterface() == propertiesInterface);
     });
     if (it == end) {
-        qCWarning(KDECONNECT_PLUGIN_MPRIS) << "PropertiesChanged signal received for no longer tracked service" << propertiesInterface->service();
+        qCWarning(KDECONNECT_PLUGIN_MPRISCONTROL) << "PropertiesChanged signal received for no longer tracked service" << propertiesInterface->service();
         return;
     }
 
@@ -147,9 +145,9 @@ void MprisControlPlugin::propertiesChanged(const QString &propertyInterface, con
         }
     }
     if (properties.contains(QStringLiteral("Metadata"))) {
-        QDBusArgument bullshit = qvariant_cast<QDBusArgument>(properties[QStringLiteral("Metadata")]);
+        QDBusArgument aux = qvariant_cast<QDBusArgument>(properties[QStringLiteral("Metadata")]);
         QVariantMap nowPlayingMap;
-        bullshit >> nowPlayingMap;
+        aux >> nowPlayingMap;
 
         mprisPlayerMetadataToNetworkPacket(np, nowPlayingMap);
         somethingToSend = true;
@@ -183,15 +181,13 @@ void MprisControlPlugin::propertiesChanged(const QString &propertyInterface, con
         np.set(QStringLiteral("canGoPrevious"), properties[QStringLiteral("CanGoPrevious")].toBool());
         somethingToSend = true;
     }
-    if (properties.contains(QStringLiteral("CanSeek"))) {
-        np.set(QStringLiteral("canSeek"), properties[QStringLiteral("CanSeek")].toBool());
-        somethingToSend = true;
-    }
 
     if (somethingToSend) {
         np.set(QStringLiteral("player"), playerName);
-        // Always also update the position
-        if (mediaPlayer2PlayerInterface->canSeek()) {
+        // Always also update the position if can seek
+        bool canSeek = mediaPlayer2PlayerInterface->canSeek();
+        np.set(QStringLiteral("canSeek"), canSeek);
+        if (canSeek) {
             long long pos = mediaPlayer2PlayerInterface->position();
             np.set(QStringLiteral("pos"), pos / 1000); // Send milis instead of nanos
         }
@@ -206,12 +202,12 @@ void MprisControlPlugin::removePlayer(const QString &serviceName)
         return (player.serviceName() == serviceName);
     });
     if (it == end) {
-        qCWarning(KDECONNECT_PLUGIN_MPRIS) << "Could not find player for serviceName" << serviceName;
+        qCWarning(KDECONNECT_PLUGIN_MPRISCONTROL) << "Could not find player for serviceName" << serviceName;
         return;
     }
 
     const QString &playerName = it.key();
-    qCDebug(KDECONNECT_PLUGIN_MPRIS) << "Mpris removePlayer" << serviceName << "->" << playerName;
+    qCDebug(KDECONNECT_PLUGIN_MPRISCONTROL) << "Mpris removePlayer" << serviceName << "->" << playerName;
 
     playerList.erase(it);
 
@@ -256,14 +252,15 @@ bool MprisControlPlugin::sendAlbumArt(const NetworkPacket &np)
     return true;
 }
 
-bool MprisControlPlugin::receivePacket(const NetworkPacket &np)
+void MprisControlPlugin::receivePacket(const NetworkPacket &np)
 {
     if (np.has(QStringLiteral("playerList"))) {
-        return false; // Whoever sent this is an mpris client and not an mpris control!
+        return; // Whoever sent this is an mpris client and not an mpris control!
     }
 
     if (np.has(QStringLiteral("albumArtUrl"))) {
-        return sendAlbumArt(np);
+        sendAlbumArt(np);
+        return;
     }
 
     // Send the player list
@@ -273,7 +270,7 @@ bool MprisControlPlugin::receivePacket(const NetworkPacket &np)
     if (!valid_player || np.get<bool>(QStringLiteral("requestPlayerList"))) {
         sendPlayerList();
         if (!valid_player) {
-            return true;
+            return;
         }
     }
 
@@ -290,17 +287,17 @@ bool MprisControlPlugin::receivePacket(const NetworkPacket &np)
     }
     if (np.has(QStringLiteral("setLoopStatus"))) {
         const QString &loopStatus = np.get<QString>(QStringLiteral("setLoopStatus"));
-        qCDebug(KDECONNECT_PLUGIN_MPRIS) << "Setting loopStatus" << loopStatus << "to" << serviceName;
+        qCDebug(KDECONNECT_PLUGIN_MPRISCONTROL) << "Setting loopStatus" << loopStatus << "to" << serviceName;
         mprisInterface.setLoopStatus(loopStatus);
     }
     if (np.has(QStringLiteral("setShuffle"))) {
         bool shuffle = np.get<bool>(QStringLiteral("setShuffle"));
-        qCDebug(KDECONNECT_PLUGIN_MPRIS) << "Setting shuffle" << shuffle << "to" << serviceName;
+        qCDebug(KDECONNECT_PLUGIN_MPRISCONTROL) << "Setting shuffle" << shuffle << "to" << serviceName;
         mprisInterface.setShuffle(shuffle);
     }
     if (np.has(QStringLiteral("setVolume"))) {
         double volume = np.get<int>(QStringLiteral("setVolume")) / 100.f;
-        qCDebug(KDECONNECT_PLUGIN_MPRIS) << "Setting volume" << volume << "to" << serviceName;
+        qCDebug(KDECONNECT_PLUGIN_MPRISCONTROL) << "Setting volume" << volume << "to" << serviceName;
         mprisInterface.setVolume(volume);
     }
     if (np.has(QStringLiteral("Seek"))) {
@@ -359,8 +356,6 @@ bool MprisControlPlugin::receivePacket(const NetworkPacket &np)
         answer.set(QStringLiteral("player"), player);
         sendPacket(answer);
     }
-
-    return true;
 }
 
 void MprisControlPlugin::sendPlayerList()
@@ -388,17 +383,10 @@ void MprisControlPlugin::mprisPlayerMetadataToNetworkPacket(NetworkPacket &np, c
         }
     }
 
-    QString nowPlaying = title;
-
-    if (!artist.isEmpty()) {
-        nowPlaying = artist + QStringLiteral(" - ") + title;
-    }
-
     np.set(QStringLiteral("title"), title);
     np.set(QStringLiteral("artist"), artist);
     np.set(QStringLiteral("album"), album);
     np.set(QStringLiteral("albumArtUrl"), albumArtUrl);
-    np.set(QStringLiteral("nowPlaying"), nowPlaying);
 
     bool hasLength = false;
     long long length = nowPlayingMap[QStringLiteral("mpris:length")].toLongLong(&hasLength) / 1000; // nanoseconds to milliseconds
@@ -409,4 +397,5 @@ void MprisControlPlugin::mprisPlayerMetadataToNetworkPacket(NetworkPacket &np, c
     np.set(QStringLiteral("url"), fileUrl);
 }
 
+#include "moc_mpriscontrolplugin.cpp"
 #include "mpriscontrolplugin.moc"
