@@ -24,10 +24,10 @@
 
 #include <dbushelper.h>
 
-K_PLUGIN_FACTORY(ShareConfigFactory, registerPlugin<RunCommandConfig>();)
+K_PLUGIN_CLASS(RunCommandConfig)
 
-RunCommandConfig::RunCommandConfig(QWidget *parent, const QVariantList &args)
-    : KdeConnectPluginKcm(parent, args, QStringLiteral("kdeconnect_runcommand"))
+RunCommandConfig::RunCommandConfig(QObject *parent, const KPluginMetaData &data, const QVariantList &args)
+    : KdeConnectPluginKcm(parent, data, args)
 {
     // The qdbus executable name is different on some systems
     QString qdbusExe = QStringLiteral("qdbus-qt5");
@@ -35,7 +35,7 @@ RunCommandConfig::RunCommandConfig(QWidget *parent, const QVariantList &args)
         qdbusExe = QStringLiteral("qdbus");
     }
 
-    QMenu *defaultMenu = new QMenu(this);
+    QMenu *defaultMenu = new QMenu(widget());
 
 #ifdef Q_OS_WIN
     addSuggestedCommand(defaultMenu, i18n("Schedule a shutdown"), QStringLiteral("shutdown /s /t 60"));
@@ -67,39 +67,35 @@ RunCommandConfig::RunCommandConfig(QWidget *parent, const QVariantList &args)
                         QStringLiteral("%0 org.kde.kded5 /modules/plasmavault forceCloseAllVaults").arg(qdbusExe));
 #endif
 
-    QTableView *table = new QTableView(this);
+    QTableView *table = new QTableView(widget());
     table->horizontalHeader()->setStretchLastSection(true);
     table->verticalHeader()->setVisible(false);
-    QVBoxLayout *layout = new QVBoxLayout(this);
-    layout->addWidget(table);
-    QPushButton *button = new QPushButton(QIcon::fromTheme(QStringLiteral("list-add")), i18n("Sample commands"), this);
+    QPushButton *button = new QPushButton(QIcon::fromTheme(QStringLiteral("list-add")), i18n("Sample commands"), widget());
     button->setMenu(defaultMenu);
-    layout->addWidget(button);
 
-    QHBoxLayout *importExportLayout = new QHBoxLayout(this);
-    QPushButton *exportButton = new QPushButton(i18n("Export"), this);
+    QHBoxLayout *importExportLayout = new QHBoxLayout();
+    QPushButton *exportButton = new QPushButton(i18n("Export"), widget());
     importExportLayout->addWidget(exportButton);
     connect(exportButton, &QPushButton::clicked, this, &RunCommandConfig::exportCommands);
-    QPushButton *importButton = new QPushButton(i18n("Import"), this);
+    QPushButton *importButton = new QPushButton(i18n("Import"), widget());
     importExportLayout->addWidget(importButton);
     connect(importButton, &QPushButton::clicked, this, &RunCommandConfig::importCommands);
-    layout->addLayout(importExportLayout);
 
-    setLayout(layout);
+    QVBoxLayout *layout = new QVBoxLayout();
+    layout->addWidget(table);
+    layout->addLayout(importExportLayout);
+    layout->addWidget(button);
+    widget()->setLayout(layout);
 
     m_entriesModel = new QStandardItemModel(this);
     table->setModel(m_entriesModel);
 
-    m_entriesModel->setHorizontalHeaderLabels(QStringList() << i18n("Name") << i18n("Command"));
-}
-
-RunCommandConfig::~RunCommandConfig()
-{
+    m_entriesModel->setHorizontalHeaderLabels(QStringList{i18n("Name"), i18n("Command")});
 }
 
 void RunCommandConfig::exportCommands()
 {
-    QString filePath = QFileDialog::getSaveFileName(this, i18n("Export Commands"), QDir::homePath(), QStringLiteral("JSON (*.json)"));
+    QString filePath = QFileDialog::getSaveFileName(widget(), i18n("Export Commands"), QDir::homePath(), QStringLiteral("JSON (*.json)"));
     if (filePath.isEmpty())
         return;
 
@@ -124,7 +120,7 @@ void RunCommandConfig::exportCommands()
 
 void RunCommandConfig::importCommands()
 {
-    QString filePath = QFileDialog::getOpenFileName(this, i18n("Import Commands"), QDir::homePath(), QStringLiteral("JSON (*.json)"));
+    QString filePath = QFileDialog::getOpenFileName(widget(), i18n("Import Commands"), QDir::homePath(), QStringLiteral("JSON (*.json)"));
     if (filePath.isEmpty())
         return;
 
@@ -155,7 +151,7 @@ void RunCommandConfig::importCommands()
         insertRow(m_entriesModel->rowCount(), name, command);
     }
 
-    Q_EMIT changed(true);
+    markAsChanged();
 }
 
 void RunCommandConfig::addSuggestedCommand(QMenu *menu, const QString &name, const QString &command)
@@ -163,7 +159,7 @@ void RunCommandConfig::addSuggestedCommand(QMenu *menu, const QString &name, con
     auto action = new QAction(name);
     connect(action, &QAction::triggered, action, [this, name, command]() {
         insertRow(0, name, command);
-        Q_EMIT changed(true);
+        markAsChanged();
     });
     menu->addAction(action);
 }
@@ -173,7 +169,7 @@ void RunCommandConfig::defaults()
     KCModule::defaults();
     m_entriesModel->removeRows(0, m_entriesModel->rowCount());
 
-    Q_EMIT changed(true);
+    markAsChanged();
 }
 
 void RunCommandConfig::load()
@@ -201,12 +197,11 @@ void RunCommandConfig::load()
 
     insertEmptyRow();
     connect(m_entriesModel, &QAbstractItemModel::dataChanged, this, &RunCommandConfig::onDataChanged);
-
-    Q_EMIT changed(false);
 }
 
 void RunCommandConfig::save()
 {
+    KCModule::save();
     QJsonObject jsonConfig;
     for (int i = 0; i < m_entriesModel->rowCount(); i++) {
         QString key = m_entriesModel->item(i, 0)->data().toString();
@@ -229,10 +224,6 @@ void RunCommandConfig::save()
     QJsonDocument document;
     document.setObject(jsonConfig);
     config()->set(QStringLiteral("commands"), document.toJson(QJsonDocument::Compact));
-
-    KCModule::save();
-
-    Q_EMIT changed(false);
 }
 
 void RunCommandConfig::insertEmptyRow()
@@ -250,14 +241,14 @@ void RunCommandConfig::insertRow(int i, const QString &name, const QString &comm
     m_entriesModel->insertRow(i, QList<QStandardItem *>() << newName << newCommand);
 }
 
-void RunCommandConfig::onDataChanged(const QModelIndex &topLeft, const QModelIndex &bottomRight)
+void RunCommandConfig::onDataChanged(const QModelIndex & /*topLeft*/, const QModelIndex &bottomRight)
 {
-    Q_EMIT changed(true);
-    Q_UNUSED(topLeft);
+    markAsChanged();
     if (bottomRight.row() == m_entriesModel->rowCount() - 1) {
         // TODO check both entries are still empty
         insertEmptyRow();
     }
 }
 
+#include "moc_runcommand_config.cpp"
 #include "runcommand_config.moc"
